@extends($activeTemplate . 'layouts.master')
@section('content')
    <div class="container">
        <div class="row justify-content-center gy-4">
            @if (!auth()->user()->ts)
                <div class="col-md-6">
                    <div class="card custom--card">

                        <div class="card-body">
                            <h5 class="card-title text-center">@lang('Add Your Account')</h5>
                            <p class="my-3 mb-3">
                                @lang('Use the QR code or setup key on your Google Authenticator app to add your account. ')
                            </p>

                            <div class="form-group mx-auto text-center">
                                <img class="mx-auto" src="{{ $qrCodeUrl }}">
                            </div>

                            <div class="form-group">
                                <label class="form-label">@lang('Setup Key')</label>
                                <div class="input-group">
                                    <input class="form--control referralURL" name="key" type="text" value="{{ $secret }}" readonly>
                                    <button class="input-group-text copytext" id="copyBoard" type="button"> <i class="fa fa-copy"></i> </button>
                                </div>
                            </div>

                            <label><i class="fa fa-info-circle"></i> @lang('Help')</label>
                            <p>@lang('Google Authenticator is a multifactor app for mobile devices. It generates timed codes used during the 2-step verification process. To use Google Authenticator, install the Google Authenticator application on your mobile device.') <a class="text--base" href="https://play.google.com/store/apps/details?id=com.google.android.apps.authenticator2&hl=en" target="_blank">@lang('Download')</a></p>
                        </div>
                    </div>
                </div>
            @endif

            <div class="col-md-6">

                @if (auth()->user()->ts)
                    <div class="card custom--card">
                        <div class="card-body">
                            <h5 class="card-title text-center">@lang('Disable 2FA Security')</h5>
                            <form action="{{ route('user.twofactor.disable') }}" method="POST">
                                @csrf
                                <input name="key" type="hidden" value="{{ $secret }}">
                                <div class="form-group">
                                    <label class="form-label">@lang('Google Authenticator OTP')</label>
                                    <input class="form--control" name="code" type="text" required>
                                </div>
                                <button class="btn btn-md btn--base w-100" type="submit">@lang('Submit')</button>
                            </form>
                        </div>
                    </div>
                @else
                    <div class="card custom--card">
                        <div class="card-body">
                            <h5 class="card-title text-center">@lang('Enable 2FA Security')</h5>
                            <form action="{{ route('user.twofactor.enable') }}" method="POST">
                                @csrf
                                <input name="key" type="hidden" value="{{ $secret }}">
                                <div class="form-group">
                                    <label class="form-label">@lang('Google Authenticator OTP')</label>
                                    <input class="form--control" name="code" type="text" required>
                                </div>
                                <button class="btn btn-md btn--base w-100" type="submit">@lang('Submit')</button>
                            </form>
                        </div>
                    </div>
                @endif
            </div>
        </div>
    </div>
@endsection

@push('style')
    <style>
        .copied::after {
            background-color: #{{ $general->base_color }};
        }

        .form--control[readonly] {
            background-color: #ffffff;
        }
    </style>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";
            $('#copyBoard').click(function() {
                var copyText = document.getElementsByClassName("referralURL");
                copyText = copyText[0];
                copyText.select();
                copyText.setSelectionRange(0, 99999);
                /*For mobile devices*/
                document.execCommand("copy");
                copyText.blur();
                this.classList.add('copied');
                setTimeout(() => this.classList.remove('copied'), 1500);
            });
        })(jQuery);
    </script>
@endpush

@push('bottom-menu')
    <li><a href="{{ route('user.profile.setting') }}">@lang('Profile')</a></li>
    <li><a href="{{ route('user.referral.users') }}">@lang('Referral')</a></li>
    <li><a class="active" href="{{ route('user.twofactor') }}">@lang('2FA Security')</a></li>
    <li><a href="{{ route('user.change.password') }}">@lang('Change Password')</a></li>
    <li><a href="{{ route('user.transaction.history') }}">@lang('Transactions')</a></li>
    <li><a class="{{ menuActive(['ticket.*']) }}" href="{{ route('ticket.index') }}">@lang('Support Tickets')</a></li>
@endpush
